﻿<template>
  <div class="wcsAlarmInfo-container">
    <el-card shadow="hover" :body-style="{ paddingBottom: '0' }"> 
      <el-form :model="queryParams" ref="queryForm" labelWidth="90">
        <el-row>
          <el-col :xs="24" :sm="12" :md="12" :lg="8" :xl="4" class="mb10">
            <el-form-item label="关键字">
              <el-input v-model="queryParams.searchKey" clearable="" placeholder="请输入模糊查询关键字"/>
              
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="12" :md="12" :lg="8" :xl="4" class="mb10" v-if="showAdvanceQueryUI">
            <el-form-item label="PLCIP地址">
              <el-input v-model="queryParams.plcIP" clearable="" placeholder="请输入PLCIP地址"/>
              
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="12" :md="12" :lg="8" :xl="4" class="mb10" v-if="showAdvanceQueryUI">
            <el-form-item label="状态">
              <el-select clearable="" v-model="queryParams.status" placeholder="请选择状态">
                <el-option v-for="(item,index) in dl('YesNoEnum')" :key="index" :value="item.value" :label="`${item.name} (${item.code}) [${item.value}] `" />
                
              </el-select>
              
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="12" :md="12" :lg="8" :xl="4" class="mb10" v-if="showAdvanceQueryUI">
            <el-form-item label="设备类型">
              <el-select clearable="" v-model="queryParams.type" placeholder="请选择设备类型">
                <el-option v-for="(item,index) in dl('PLCTypeEnum')" :key="index" :value="item.value" :label="`${item.name} (${item.code}) [${item.value}] `" />
                
              </el-select>
              
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="12" :md="12" :lg="8" :xl="4" class="mb10">
            <el-form-item >
              <el-button-group style="display: flex; align-items: center;">
                <el-button type="primary"  icon="ele-Search" @click="handleQuery" v-auth="'wcsAlarmInfo:page'"> 查询 </el-button>
                      <el-button icon="ele-Refresh" @click="() => queryParams = {}"> 重置 </el-button>
                        <el-button icon="ele-ZoomIn" @click="changeAdvanceQueryUI" v-if="!showAdvanceQueryUI" style="margin-left:5px;"> 高级查询 </el-button>
                        <el-button icon="ele-ZoomOut" @click="changeAdvanceQueryUI" v-if="showAdvanceQueryUI" style="margin-left:5px;"> 隐藏 </el-button>
                <el-button type="primary" style="margin-left:5px;" icon="ele-Plus" @click="openAddWcsAlarmInfo" v-auth="'wcsAlarmInfo:add'"> 新增 </el-button>
                
              </el-button-group>
            </el-form-item>
            
          </el-col>
        </el-row>
      </el-form>
    </el-card>
    <el-card class="full-table" shadow="hover" style="margin-top: 5px">
      <el-table :data="tableData" style="width: 100%" v-loading="loading" tooltip-effect="light" row-key="id"
        @sort-change="sortChange" border="">
        <el-table-column type="index" label="序号" width="55" align="center" />
        <el-table-column prop="plcIP" label="PLCIP地址" show-overflow-tooltip="" />
        <el-table-column prop="plcPort" label="PLCIP端口" show-overflow-tooltip="" />
        <el-table-column prop="stationNum" label="工位号" show-overflow-tooltip="" />
        <el-table-column prop="alarmCode" label="报警编号" show-overflow-tooltip="" />
        <el-table-column prop="alarmName" label="报警描述" show-overflow-tooltip="" />
        <el-table-column prop="ledIP" label="显示屏ip地址" show-overflow-tooltip="" />
        <el-table-column prop="status" label="状态" show-overflow-tooltip="">
          <template #default="scope">
            <el-tag :type="dv('YesNoEnum', scope.row.status)?.tagType"> {{ dv('YesNoEnum',
              scope.row.status)?.name}}</el-tag>
          </template>
        </el-table-column>
        <el-table-column prop="type" label="设备类型" show-overflow-tooltip="">
          <template #default="scope">
            <el-tag :type="dv('PLCTypeEnum', scope.row.type)?.tagType"> {{ dv('PLCTypeEnum',
              scope.row.type)?.name}}</el-tag>
          </template>
        </el-table-column>
        <el-table-column prop="alarmTime" label="报警日期" show-overflow-tooltip="" />
        <el-table-column prop="ledStatus" label="LED状态" show-overflow-tooltip="">
          <template #default="scope">
            <el-tag :type="dv('YesNoEnum', scope.row.ledStatus)?.tagType"> {{ dv('YesNoEnum',
              scope.row.ledStatus)?.name}}</el-tag>
          </template>
        </el-table-column>
        <el-table-column label="修改记录" width="80" align="center" show-overflow-tooltip>
          <template #default="scope">
            <ModifyRecord :data="scope.row" />
          </template>
        </el-table-column>
        <el-table-column label="操作" width="140" align="center" fixed="right" show-overflow-tooltip=""
          v-if="auth('wcsAlarmInfo:update') || auth('wcsAlarmInfo:delete')">
          <template #default="scope">
            <el-button icon="ele-Edit" size="small" text="" type="primary" @click="openEditWcsAlarmInfo(scope.row)"
              v-auth="'wcsAlarmInfo:update'"> 编辑 </el-button>
            <el-button icon="ele-Delete" size="small" text="" type="primary" @click="delWcsAlarmInfo(scope.row)"
              v-auth="'wcsAlarmInfo:delete'"> 删除 </el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination v-model:currentPage="tableParams.page" v-model:page-size="tableParams.pageSize"
        :total="tableParams.total" :page-sizes="[10, 20, 50, 100, 200, 500]" size="small" background=""
        @size-change="handleSizeChange" @current-change="handleCurrentChange"
        layout="total, sizes, prev, pager, next, jumper" />
      <printDialog ref="printDialogRef" :title="printWcsAlarmInfoTitle" @reloadTable="handleQuery" />
      <editDialog ref="editDialogRef" :title="editWcsAlarmInfoTitle" @reloadTable="handleQuery" />
    </el-card>
  </div>
</template>

<script lang="ts" setup="" name="wcsAlarmInfo">
import { ref } from "vue";
import { ElMessageBox, ElMessage } from "element-plus";
import { auth } from '/@/utils/authFunction';

import { getDictDataItem as di, getDictDataList as dl } from '/@/utils/dict-utils';
import { getDictLabelByVal as dv } from '/@/utils/dict-utils';
import { formatDate } from '/@/utils/formatTime';

import ModifyRecord from '/@/components/table/modifyRecord.vue';

import printDialog from '/@/views/system/print/component/hiprint/preview.vue'
import editDialog from '/@/views/wcs/wcsAlarmInfo/component/editDialog.vue'
import { pageWcsAlarmInfo, deleteWcsAlarmInfo } from '/@/api/wcs/wcsAlarmInfo';

const showAdvanceQueryUI = ref(false);
const printDialogRef = ref();
const editDialogRef = ref();
const loading = ref(false);
const tableData = ref<any>([]);
const queryParams = ref<any>({});
const tableParams = ref({
  page: 1,
  pageSize: 10,
  total: 0,
});

const printWcsAlarmInfoTitle = ref("");
const editWcsAlarmInfoTitle = ref("");

// 改变高级查询的控件显示状态
const changeAdvanceQueryUI = () => {
  showAdvanceQueryUI.value = !showAdvanceQueryUI.value;
}

// 查询操作
const handleQuery = async () => {
  loading.value = true;
  var res = await pageWcsAlarmInfo(Object.assign(queryParams.value, tableParams.value));
  tableData.value = res.data.result?.items ?? [];
  tableParams.value.total = res.data.result?.total;
  loading.value = false;
};

// 列排序
const sortChange = async (column: any) => {
  queryParams.value.field = column.prop;
  queryParams.value.order = column.order;
  await handleQuery();
};

// 打开新增页面
const openAddWcsAlarmInfo = () => {
  editWcsAlarmInfoTitle.value = '添加报警信息表';
  editDialogRef.value.openDialog({});
};

// 打开打印页面
const openPrintWcsAlarmInfo = async (row: any) => {
  printWcsAlarmInfoTitle.value = '打印报警信息表';
}

// 打开编辑页面
const openEditWcsAlarmInfo = (row: any) => {
  editWcsAlarmInfoTitle.value = '编辑报警信息表';
  editDialogRef.value.openDialog(row);
};

// 删除
const delWcsAlarmInfo = (row: any) => {
  ElMessageBox.confirm(`确定要删除吗?`, "提示", {
    confirmButtonText: "确定",
    cancelButtonText: "取消",
    type: "warning",
  })
    .then(async () => {
      await deleteWcsAlarmInfo(row);
      handleQuery();
      ElMessage.success("删除成功");
    })
    .catch(() => { });
};

// 改变页面容量
const handleSizeChange = (val: number) => {
  tableParams.value.pageSize = val;
  handleQuery();
};

// 改变页码序号
const handleCurrentChange = (val: number) => {
  tableParams.value.page = val;
  handleQuery();
};

handleQuery();
</script>
<style scoped>
:deep(.el-input),
:deep(.el-select),
:deep(.el-input-number) {
  width: 100%;
}
</style>
